@@ -226,6 +226,7 @@ namespace giac {
 	return zero;
       if (a._VECTptr->size()==1)
 	return a._VECTptr->front();
+      // a.subtype=_POLY1__VECT;
     }
     gen res;
 #ifdef SMARTPTR64
@@ -235,6 +236,7 @@ namespace giac {
 #endif
     res.type=_EXT;
     *(res._EXTptr+1) = v;
+    // if (v.type==_VECT) (res._EXTptr+1)->subtype=_POLY1__VECT;
     if (a.type==_FRAC){
       *res._EXTptr = a._FRACptr->num;
       return fraction(res,a._FRACptr->den);
@@ -387,7 +389,7 @@ namespace giac {
     for (;it!=itend;++it){
       i=it->index.front();
       j=it->index.back();
-      // cerr << nb*(na-i-1)+nb-j-1 << " " << na*nb << endl;
+      // cerr << nb*(na-i-1)+nb-j-1 << " " << na*nb << '\n';
       v[nb*(na-i-1)+nb-j-1]=it->value;
     }
     return true;
@@ -871,7 +873,7 @@ namespace giac {
       if (innerdim){
 	gen params;
 	polynome pb(1),px(unsplitmultivarpoly(p,innerdim));
-	*logptr(contextptr) << gettext("Warning, need to choose a branch for the root of a polynomial with parameters. This might be wrong.") << endl;
+	*logptr(contextptr) << gettext("Warning, need to choose a branch for the root of a polynomial with parameters. This might be wrong.") << '\n';
 	if (l && l->size()>=2){
 	  for (int i=1;i<l->size();++i){
 	    params=(*l)[i];
@@ -931,9 +933,9 @@ namespace giac {
 	vecteur vb0=vb;
 	find_good_eval(px,pb,vb); // find_good_eval does not take care of assumptions, but vb should be ok (loop above)
 	if (vb==vb0)
-	  *logptr(contextptr) << gettext("The choice was done assuming ") << params << "=" << vb << endl;       
+	  *logptr(contextptr) << gettext("The choice was done assuming ") << params << "=" << vb << '\n';       
 	else 
-	  *logptr(contextptr) << gettext("Non regular value ") << vb0 << gettext(" was discarded and replaced randomly by ") << params << "=" << vb << endl;
+	  *logptr(contextptr) << gettext("Non regular value ") << vb0 << gettext(" was discarded and replaced randomly by ") << params << "=" << vb << '\n';
 	// checking for embedded polynomial coefficients
 	vector< monomial<gen> >::const_iterator it=pb.coord.begin(),itend=pb.coord.end();
 	for (;0 && it!=itend;++it){ // disabled, computations would be too complex
@@ -951,42 +953,62 @@ namespace giac {
       // racines= list of approx roots if b__VECT is numeric
       // empty if not numeric
       racine_max=in_select_root(racines,is_real(b__VECT,contextptr),contextptr);
-    }
+    } // if (!trouve)
     if (!deep_emb && !trouve && !is_undef(racine_max)){ // select root for b
       // now eval each factor over racine_max and choose the one with
       // minimal absolute value
-      double min_abs=0;
-      for (;f_it!=f_itend;++f_it){
-	vecteur vtmp(polynome2poly1(f_it->fact));
-	gen tmp;
-	lcmdeno_converted(vtmp,tmp,contextptr);
-	int maxsave=max_sum_sqrt(contextptr);
-	max_sum_sqrt(0,contextptr);
-	if (innerdim)
-	  tmp=r2sym(vtmp,vecteur(1,vb),contextptr);
-	else
-	  tmp=r2sym(vtmp,vecteur(1,vecteur(0)),contextptr);
-	max_sum_sqrt(maxsave,contextptr);
-	tmp=evalf(tmp,1,contextptr);
-	if (tmp.type==_VECT && !tmp._VECTptr->empty())
-	  tmp=tmp/tmp._VECTptr->front();
-	gen f_racine_max(evalf_double(abs(horner(tmp,racine_max),contextptr),1,contextptr));
-	if (f_racine_max.type!=_DOUBLE_)
-	  continue;
-	double current_evaluation=fabs(f_racine_max._DOUBLE_val);
-	if (!trouve){
-	  trouve=true;
-	  min_abs=current_evaluation;
-	  p=f_it->fact;
-	}
-	else {
-	  if (min_abs>current_evaluation){
+      double min_abs=0,racine_max_d=evalf_double(abs(racine_max,contextptr),1,contextptr)._DOUBLE_val;
+      int ndig=14;
+      while (!trouve){
+	for (;f_it!=f_itend;++f_it){
+	  vecteur vtmp(polynome2poly1(f_it->fact));
+	  gen tmp;
+	  lcmdeno_converted(vtmp,tmp,contextptr);
+	  int maxsave=max_sum_sqrt(contextptr);
+	  max_sum_sqrt(0,contextptr);
+	  if (innerdim)
+	    tmp=r2sym(vtmp,vecteur(1,vb),contextptr);
+	  else
+	    tmp=r2sym(vtmp,vecteur(1,vecteur(0)),contextptr);
+	  max_sum_sqrt(maxsave,contextptr);
+#if defined HAVE_LIBMPFR && defined HAVE_LIBPARI // change for Martin Deraux big extensions
+	  if (ndig<15) 
+	    tmp=evalf(tmp,1,contextptr);
+	  else
+	    tmp=_evalf(makesequence(tmp,ndig),contextptr);
+#else 
+	  tmp=evalf(tmp,1,contextptr);
+#endif
+	  if (tmp.type==_VECT && !tmp._VECTptr->empty())
+	    tmp=tmp/tmp._VECTptr->front();
+	  gen f_racine_max(evalf_double(abs(horner(tmp,racine_max),contextptr),1,contextptr));
+	  if (f_racine_max.type!=_DOUBLE_)
+	    continue;
+	  double current_evaluation=fabs(f_racine_max._DOUBLE_val);
+	  if (!trouve){
+	    trouve=true;
 	    min_abs=current_evaluation;
 	    p=f_it->fact;
 	  }
+	  else {
+	    if (min_abs>current_evaluation){
+	      min_abs=current_evaluation;
+	      p=f_it->fact;
+	    }
+	  }
+	} // end for on f_it
+	if (min_abs>1e-4*racine_max_d){
+	  *logptr(contextptr) << "Precision problem choosing root in common_EXT, current precision " << ndig << '\n';
+	  trouve=false;
+	  ndig=2*ndig;
+	  f_it=f.begin();
+#if defined HAVE_LIBMPFR && defined HAVE_LIBPARI
+	  if (ndig>1000)
+#endif
+	    break;
 	}
-      }
-    }
+      } // end while !trouve
+    } // end racine_max defined
     if (!trouve) {
       for (;f_it!=f_itend;++f_it){
 	if ( (b.type==_EXT) && is_zero(horner(polynome2poly1(f_it->fact,1),*b._EXTptr)) ){
@@ -1162,7 +1184,7 @@ namespace giac {
       return gentypeerr(gettext("rootof"));
     }
     if (e.type==_VECT && *e._VECTptr==makevecteur(1,0,1)){
-      *logptr(contextptr) << "rootof([1,0,1]) was converted to i" << endl;
+      *logptr(contextptr) << "rootof([1,0,1]) was converted to i" << '\n';
       return cst_i;
     }
     if (e._VECTptr->size()==2 && e._VECTptr->front().type!=_VECT){
@@ -1176,7 +1198,7 @@ namespace giac {
     if (has_num_coeff(e))
       return approx_rootof(e,contextptr);
     if (!lop(lvar(e),at_pow).empty()){
-      *logptr(contextptr) << gettext("Algebraic extensions not allowed in a rootof")<<endl;
+      *logptr(contextptr) << gettext("Algebraic extensions not allowed in a rootof")<<'\n';
       return approx_rootof(e,contextptr);
     }
     // should call factor before returning unevaluated rootof
@@ -1184,6 +1206,10 @@ namespace giac {
       vecteur v2=*e._VECTptr->back()._VECTptr;
       gen g(1);
       lcmdeno(v2,g,contextptr);
+      if (is_minus_one(v2[0]))
+	v2=-v2;
+      if (!is_one(v2[0]))
+	return gensizeerr("rootof minimal polynomial must be unitary");
       return symbolic(at_rootof,gen(makevecteur(e._VECTptr->front(),gen(v2,e._VECTptr->back().subtype)),e.subtype));
     }
     return symbolic(at_rootof,e);
@@ -1378,7 +1404,7 @@ namespace giac {
     else { 
       x=v[1]; a=v[2]; b=v[3]; 
       if (P.type==_VECT)
-	*logptr(contextptr) << gettext("Warning: variable name ignored: ") << x << endl;
+	*logptr(contextptr) << gettext("Warning: variable name ignored: ") << x << '\n';
     }
     gen ai=im(a,contextptr);
     gen bi=im(b,contextptr);
@@ -1620,7 +1646,7 @@ namespace giac {
 	sto(savevar,var,contextptr);
     }
     if (w.empty() && debug_infolevel)
-      *logptr(contextptr) << gettext("Warning: ") << df << gettext("=0: no solution found") << endl;
+      *logptr(contextptr) << gettext("Warning: ") << df << gettext("=0: no solution found") << '\n';
     vecteur wvar=makevecteur(cst_pi);
     lidnt(w,wvar,false);
     if (wvar.size()>1)
