@@ -57,10 +57,10 @@ namespace giac {
     b=tmp;
   }
 
-  index_t index_gcd(const index_t & a,const index_t & b){
+  void index_gcd(const index_t & a,const index_t & b,index_t & res){
     index_t::const_iterator ita=a.begin(),itaend=a.end(),itb=b.begin();
     unsigned s=unsigned(itaend-ita);
-    index_t res(s);
+    res.resize(s);
     index_t::iterator itres=res.begin();  
 #ifdef DEBUG_SUPPORT
     if (s!=b.size())
@@ -68,6 +68,11 @@ namespace giac {
 #endif // DEBUG_SUPPORT
     for (;ita!=itaend;++itb,++itres,++ita)
       *itres=giacmin(*ita,*itb);
+  }
+
+  index_t index_gcd(const index_t & a,const index_t & b){
+    index_t res;
+    index_gcd(a,b,res);
     return res;
   }
 
@@ -218,9 +223,15 @@ namespace giac {
     return true;
   }
 
+  void add_print_INT_(string & s,int i){
+    char c[256];
+    sprint_int(c,i);//my_sprintf(c,"%d",i);
+    s += c;
+  }
+
   string print_INT_(int i){
     char c[256];
-    my_sprintf(c,"%d",i);
+    sprint_int(c,i);//my_sprintf(c,"%d",i);
     return c;
   }
 
@@ -460,7 +471,7 @@ namespace giac {
     if (((i1.taille % 2))==0){
       if (i1.riptr==i2.riptr)
 	return true;
-#if 0 // def __x86_64__
+#if 0 // def x86_64
       const index_t & i1t=i1.riptr->i;
       const index_t & i2t=i2.riptr->i;
       int n=i1t.size();
@@ -537,7 +548,7 @@ namespace giac {
 #endif // DEBUG_SUPPORT
     index_m res(s);
     deg_t * it=(deg_t*)&*res.begin();
-#if 0 // def __x86_64__
+#if 0 // def x86_64
     ulonglong * target=(ulonglong *) &*it;
     const ulonglong * ptr1=(const ulonglong *) &*ita,* ptr1end=ptr1+s/(sizeof(ulonglong)/sizeof(deg_t));
     const ulonglong * ptr2=(const ulonglong *) &*itb;
@@ -851,7 +862,7 @@ namespace giac {
 
   int nvar_total_degree(const index_m & v1,int n){
     index_t::const_iterator it1=v1.begin(),it1l=it1+n;
-    int d1,d2;
+    int d1;
     for (d1=0;it1<it1l;++it1){
       d1 += *it1;
     }
