@@ -17,9 +17,10 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "giacPCH.h"
+#include "giac.h"
 #include "lpsolve.h"
 #include "optimization.h"
-#include "giac.h"
 #include <ctime>
 
 #ifndef DBL_MAX
@@ -669,7 +670,7 @@ void lp_problem::set_objective(const vecteur &v, const gen &ft) {
  */
 void lp_problem::message(const char *msg, bool err) {
     if (err || settings.verbose)
-        *logptr(ctx) << msg << endl;
+        *logptr(ctx) << msg << "\n";
 }
 
 /*
